.. _links:

python_, and `another python`__

.. __: python_

.. _python: https://www.python.org

`and a direct anonymous link`__

.. __: https://docutils.sourceforge.io/rst.html

`example <https://www.example.com>`_

`example but anon <https://www.example.com>`__

links_

.. _indirect multiple: https://www.example.net

.. _multiple: `indirect multiple`_
